# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmSweep(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'algorithm': 'str',
        'created_dt': 'datetime',
        'early_stopping_spec': 'dict(str, object)',
        'edges': 'OrmSweepEdges',
        'env_vars': 'dict(str, object)',
        'final_cost': 'float',
        'id': 'int',
        'immutable_slug': 'str',
        'kernel_cluster_select_policies': 'dict(str, object)',
        'max_experiment_count': 'int',
        'max_failed_experiment_count': 'int',
        'message': 'str',
        'name': 'str',
        'objective': 'dict(str, object)',
        'objective_step_median': 'dict(str, object)',
        'parallel_experiment_count': 'int',
        'search_space': 'dict(str, object)',
        'start_command': 'str',
        'status': 'str',
        'status_last_updated': 'datetime',
        'status_reason': 'str',
        'suggestion_histories': 'dict(str, object)',
        'sweep_created_by': 'int',
        'sweep_kernel_cluster': 'int',
        'sweep_kernel_cluster_node': 'int',
        'sweep_kernel_image': 'int',
        'sweep_kernel_resource_spec': 'int',
        'sweep_organization': 'int',
        'sweep_project': 'int',
        'updated_dt': 'datetime',
        'volume_mounts': 'dict(str, object)'
    }

    attribute_map = {
        'algorithm': 'algorithm',
        'created_dt': 'created_dt',
        'early_stopping_spec': 'early_stopping_spec',
        'edges': 'edges',
        'env_vars': 'env_vars',
        'final_cost': 'final_cost',
        'id': 'id',
        'immutable_slug': 'immutable_slug',
        'kernel_cluster_select_policies': 'kernel_cluster_select_policies',
        'max_experiment_count': 'max_experiment_count',
        'max_failed_experiment_count': 'max_failed_experiment_count',
        'message': 'message',
        'name': 'name',
        'objective': 'objective',
        'objective_step_median': 'objective_step_median',
        'parallel_experiment_count': 'parallel_experiment_count',
        'search_space': 'search_space',
        'start_command': 'start_command',
        'status': 'status',
        'status_last_updated': 'status_last_updated',
        'status_reason': 'status_reason',
        'suggestion_histories': 'suggestion_histories',
        'sweep_created_by': 'sweep_created_by',
        'sweep_kernel_cluster': 'sweep_kernel_cluster',
        'sweep_kernel_cluster_node': 'sweep_kernel_cluster_node',
        'sweep_kernel_image': 'sweep_kernel_image',
        'sweep_kernel_resource_spec': 'sweep_kernel_resource_spec',
        'sweep_organization': 'sweep_organization',
        'sweep_project': 'sweep_project',
        'updated_dt': 'updated_dt',
        'volume_mounts': 'volume_mounts'
    }

    def __init__(self, algorithm=None, created_dt=None, early_stopping_spec=None, edges=None, env_vars=None, final_cost=None, id=None, immutable_slug=None, kernel_cluster_select_policies=None, max_experiment_count=None, max_failed_experiment_count=None, message=None, name=None, objective=None, objective_step_median=None, parallel_experiment_count=None, search_space=None, start_command=None, status=None, status_last_updated=None, status_reason=None, suggestion_histories=None, sweep_created_by=None, sweep_kernel_cluster=None, sweep_kernel_cluster_node=None, sweep_kernel_image=None, sweep_kernel_resource_spec=None, sweep_organization=None, sweep_project=None, updated_dt=None, volume_mounts=None, local_vars_configuration=None):  # noqa: E501
        """OrmSweep - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._algorithm = None
        self._created_dt = None
        self._early_stopping_spec = None
        self._edges = None
        self._env_vars = None
        self._final_cost = None
        self._id = None
        self._immutable_slug = None
        self._kernel_cluster_select_policies = None
        self._max_experiment_count = None
        self._max_failed_experiment_count = None
        self._message = None
        self._name = None
        self._objective = None
        self._objective_step_median = None
        self._parallel_experiment_count = None
        self._search_space = None
        self._start_command = None
        self._status = None
        self._status_last_updated = None
        self._status_reason = None
        self._suggestion_histories = None
        self._sweep_created_by = None
        self._sweep_kernel_cluster = None
        self._sweep_kernel_cluster_node = None
        self._sweep_kernel_image = None
        self._sweep_kernel_resource_spec = None
        self._sweep_organization = None
        self._sweep_project = None
        self._updated_dt = None
        self._volume_mounts = None
        self.discriminator = None

        if algorithm is not None:
            self.algorithm = algorithm
        if created_dt is not None:
            self.created_dt = created_dt
        if early_stopping_spec is not None:
            self.early_stopping_spec = early_stopping_spec
        if edges is not None:
            self.edges = edges
        if env_vars is not None:
            self.env_vars = env_vars
        self.final_cost = final_cost
        if id is not None:
            self.id = id
        if immutable_slug is not None:
            self.immutable_slug = immutable_slug
        if kernel_cluster_select_policies is not None:
            self.kernel_cluster_select_policies = kernel_cluster_select_policies
        if max_experiment_count is not None:
            self.max_experiment_count = max_experiment_count
        if max_failed_experiment_count is not None:
            self.max_failed_experiment_count = max_failed_experiment_count
        if message is not None:
            self.message = message
        if name is not None:
            self.name = name
        if objective is not None:
            self.objective = objective
        if objective_step_median is not None:
            self.objective_step_median = objective_step_median
        if parallel_experiment_count is not None:
            self.parallel_experiment_count = parallel_experiment_count
        if search_space is not None:
            self.search_space = search_space
        if start_command is not None:
            self.start_command = start_command
        if status is not None:
            self.status = status
        if status_last_updated is not None:
            self.status_last_updated = status_last_updated
        if status_reason is not None:
            self.status_reason = status_reason
        if suggestion_histories is not None:
            self.suggestion_histories = suggestion_histories
        if sweep_created_by is not None:
            self.sweep_created_by = sweep_created_by
        self.sweep_kernel_cluster = sweep_kernel_cluster
        self.sweep_kernel_cluster_node = sweep_kernel_cluster_node
        if sweep_kernel_image is not None:
            self.sweep_kernel_image = sweep_kernel_image
        self.sweep_kernel_resource_spec = sweep_kernel_resource_spec
        if sweep_organization is not None:
            self.sweep_organization = sweep_organization
        if sweep_project is not None:
            self.sweep_project = sweep_project
        if updated_dt is not None:
            self.updated_dt = updated_dt
        if volume_mounts is not None:
            self.volume_mounts = volume_mounts

    @property
    def algorithm(self):
        """Gets the algorithm of this OrmSweep.  # noqa: E501


        :return: The algorithm of this OrmSweep.  # noqa: E501
        :rtype: str
        """
        return self._algorithm

    @algorithm.setter
    def algorithm(self, algorithm):
        """Sets the algorithm of this OrmSweep.


        :param algorithm: The algorithm of this OrmSweep.  # noqa: E501
        :type algorithm: str
        """

        self._algorithm = algorithm

    @property
    def created_dt(self):
        """Gets the created_dt of this OrmSweep.  # noqa: E501


        :return: The created_dt of this OrmSweep.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OrmSweep.


        :param created_dt: The created_dt of this OrmSweep.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def early_stopping_spec(self):
        """Gets the early_stopping_spec of this OrmSweep.  # noqa: E501


        :return: The early_stopping_spec of this OrmSweep.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._early_stopping_spec

    @early_stopping_spec.setter
    def early_stopping_spec(self, early_stopping_spec):
        """Sets the early_stopping_spec of this OrmSweep.


        :param early_stopping_spec: The early_stopping_spec of this OrmSweep.  # noqa: E501
        :type early_stopping_spec: dict(str, object)
        """

        self._early_stopping_spec = early_stopping_spec

    @property
    def edges(self):
        """Gets the edges of this OrmSweep.  # noqa: E501


        :return: The edges of this OrmSweep.  # noqa: E501
        :rtype: OrmSweepEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmSweep.


        :param edges: The edges of this OrmSweep.  # noqa: E501
        :type edges: OrmSweepEdges
        """

        self._edges = edges

    @property
    def env_vars(self):
        """Gets the env_vars of this OrmSweep.  # noqa: E501


        :return: The env_vars of this OrmSweep.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._env_vars

    @env_vars.setter
    def env_vars(self, env_vars):
        """Sets the env_vars of this OrmSweep.


        :param env_vars: The env_vars of this OrmSweep.  # noqa: E501
        :type env_vars: dict(str, object)
        """

        self._env_vars = env_vars

    @property
    def final_cost(self):
        """Gets the final_cost of this OrmSweep.  # noqa: E501


        :return: The final_cost of this OrmSweep.  # noqa: E501
        :rtype: float
        """
        return self._final_cost

    @final_cost.setter
    def final_cost(self, final_cost):
        """Sets the final_cost of this OrmSweep.


        :param final_cost: The final_cost of this OrmSweep.  # noqa: E501
        :type final_cost: float
        """

        self._final_cost = final_cost

    @property
    def id(self):
        """Gets the id of this OrmSweep.  # noqa: E501


        :return: The id of this OrmSweep.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmSweep.


        :param id: The id of this OrmSweep.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def immutable_slug(self):
        """Gets the immutable_slug of this OrmSweep.  # noqa: E501


        :return: The immutable_slug of this OrmSweep.  # noqa: E501
        :rtype: str
        """
        return self._immutable_slug

    @immutable_slug.setter
    def immutable_slug(self, immutable_slug):
        """Sets the immutable_slug of this OrmSweep.


        :param immutable_slug: The immutable_slug of this OrmSweep.  # noqa: E501
        :type immutable_slug: str
        """

        self._immutable_slug = immutable_slug

    @property
    def kernel_cluster_select_policies(self):
        """Gets the kernel_cluster_select_policies of this OrmSweep.  # noqa: E501


        :return: The kernel_cluster_select_policies of this OrmSweep.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._kernel_cluster_select_policies

    @kernel_cluster_select_policies.setter
    def kernel_cluster_select_policies(self, kernel_cluster_select_policies):
        """Sets the kernel_cluster_select_policies of this OrmSweep.


        :param kernel_cluster_select_policies: The kernel_cluster_select_policies of this OrmSweep.  # noqa: E501
        :type kernel_cluster_select_policies: dict(str, object)
        """

        self._kernel_cluster_select_policies = kernel_cluster_select_policies

    @property
    def max_experiment_count(self):
        """Gets the max_experiment_count of this OrmSweep.  # noqa: E501


        :return: The max_experiment_count of this OrmSweep.  # noqa: E501
        :rtype: int
        """
        return self._max_experiment_count

    @max_experiment_count.setter
    def max_experiment_count(self, max_experiment_count):
        """Sets the max_experiment_count of this OrmSweep.


        :param max_experiment_count: The max_experiment_count of this OrmSweep.  # noqa: E501
        :type max_experiment_count: int
        """

        self._max_experiment_count = max_experiment_count

    @property
    def max_failed_experiment_count(self):
        """Gets the max_failed_experiment_count of this OrmSweep.  # noqa: E501


        :return: The max_failed_experiment_count of this OrmSweep.  # noqa: E501
        :rtype: int
        """
        return self._max_failed_experiment_count

    @max_failed_experiment_count.setter
    def max_failed_experiment_count(self, max_failed_experiment_count):
        """Sets the max_failed_experiment_count of this OrmSweep.


        :param max_failed_experiment_count: The max_failed_experiment_count of this OrmSweep.  # noqa: E501
        :type max_failed_experiment_count: int
        """

        self._max_failed_experiment_count = max_failed_experiment_count

    @property
    def message(self):
        """Gets the message of this OrmSweep.  # noqa: E501


        :return: The message of this OrmSweep.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this OrmSweep.


        :param message: The message of this OrmSweep.  # noqa: E501
        :type message: str
        """

        self._message = message

    @property
    def name(self):
        """Gets the name of this OrmSweep.  # noqa: E501


        :return: The name of this OrmSweep.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OrmSweep.


        :param name: The name of this OrmSweep.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def objective(self):
        """Gets the objective of this OrmSweep.  # noqa: E501


        :return: The objective of this OrmSweep.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._objective

    @objective.setter
    def objective(self, objective):
        """Sets the objective of this OrmSweep.


        :param objective: The objective of this OrmSweep.  # noqa: E501
        :type objective: dict(str, object)
        """

        self._objective = objective

    @property
    def objective_step_median(self):
        """Gets the objective_step_median of this OrmSweep.  # noqa: E501


        :return: The objective_step_median of this OrmSweep.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._objective_step_median

    @objective_step_median.setter
    def objective_step_median(self, objective_step_median):
        """Sets the objective_step_median of this OrmSweep.


        :param objective_step_median: The objective_step_median of this OrmSweep.  # noqa: E501
        :type objective_step_median: dict(str, object)
        """

        self._objective_step_median = objective_step_median

    @property
    def parallel_experiment_count(self):
        """Gets the parallel_experiment_count of this OrmSweep.  # noqa: E501


        :return: The parallel_experiment_count of this OrmSweep.  # noqa: E501
        :rtype: int
        """
        return self._parallel_experiment_count

    @parallel_experiment_count.setter
    def parallel_experiment_count(self, parallel_experiment_count):
        """Sets the parallel_experiment_count of this OrmSweep.


        :param parallel_experiment_count: The parallel_experiment_count of this OrmSweep.  # noqa: E501
        :type parallel_experiment_count: int
        """

        self._parallel_experiment_count = parallel_experiment_count

    @property
    def search_space(self):
        """Gets the search_space of this OrmSweep.  # noqa: E501


        :return: The search_space of this OrmSweep.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._search_space

    @search_space.setter
    def search_space(self, search_space):
        """Sets the search_space of this OrmSweep.


        :param search_space: The search_space of this OrmSweep.  # noqa: E501
        :type search_space: dict(str, object)
        """

        self._search_space = search_space

    @property
    def start_command(self):
        """Gets the start_command of this OrmSweep.  # noqa: E501


        :return: The start_command of this OrmSweep.  # noqa: E501
        :rtype: str
        """
        return self._start_command

    @start_command.setter
    def start_command(self, start_command):
        """Sets the start_command of this OrmSweep.


        :param start_command: The start_command of this OrmSweep.  # noqa: E501
        :type start_command: str
        """

        self._start_command = start_command

    @property
    def status(self):
        """Gets the status of this OrmSweep.  # noqa: E501


        :return: The status of this OrmSweep.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this OrmSweep.


        :param status: The status of this OrmSweep.  # noqa: E501
        :type status: str
        """

        self._status = status

    @property
    def status_last_updated(self):
        """Gets the status_last_updated of this OrmSweep.  # noqa: E501


        :return: The status_last_updated of this OrmSweep.  # noqa: E501
        :rtype: datetime
        """
        return self._status_last_updated

    @status_last_updated.setter
    def status_last_updated(self, status_last_updated):
        """Sets the status_last_updated of this OrmSweep.


        :param status_last_updated: The status_last_updated of this OrmSweep.  # noqa: E501
        :type status_last_updated: datetime
        """

        self._status_last_updated = status_last_updated

    @property
    def status_reason(self):
        """Gets the status_reason of this OrmSweep.  # noqa: E501


        :return: The status_reason of this OrmSweep.  # noqa: E501
        :rtype: str
        """
        return self._status_reason

    @status_reason.setter
    def status_reason(self, status_reason):
        """Sets the status_reason of this OrmSweep.


        :param status_reason: The status_reason of this OrmSweep.  # noqa: E501
        :type status_reason: str
        """

        self._status_reason = status_reason

    @property
    def suggestion_histories(self):
        """Gets the suggestion_histories of this OrmSweep.  # noqa: E501


        :return: The suggestion_histories of this OrmSweep.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._suggestion_histories

    @suggestion_histories.setter
    def suggestion_histories(self, suggestion_histories):
        """Sets the suggestion_histories of this OrmSweep.


        :param suggestion_histories: The suggestion_histories of this OrmSweep.  # noqa: E501
        :type suggestion_histories: dict(str, object)
        """

        self._suggestion_histories = suggestion_histories

    @property
    def sweep_created_by(self):
        """Gets the sweep_created_by of this OrmSweep.  # noqa: E501


        :return: The sweep_created_by of this OrmSweep.  # noqa: E501
        :rtype: int
        """
        return self._sweep_created_by

    @sweep_created_by.setter
    def sweep_created_by(self, sweep_created_by):
        """Sets the sweep_created_by of this OrmSweep.


        :param sweep_created_by: The sweep_created_by of this OrmSweep.  # noqa: E501
        :type sweep_created_by: int
        """

        self._sweep_created_by = sweep_created_by

    @property
    def sweep_kernel_cluster(self):
        """Gets the sweep_kernel_cluster of this OrmSweep.  # noqa: E501


        :return: The sweep_kernel_cluster of this OrmSweep.  # noqa: E501
        :rtype: int
        """
        return self._sweep_kernel_cluster

    @sweep_kernel_cluster.setter
    def sweep_kernel_cluster(self, sweep_kernel_cluster):
        """Sets the sweep_kernel_cluster of this OrmSweep.


        :param sweep_kernel_cluster: The sweep_kernel_cluster of this OrmSweep.  # noqa: E501
        :type sweep_kernel_cluster: int
        """

        self._sweep_kernel_cluster = sweep_kernel_cluster

    @property
    def sweep_kernel_cluster_node(self):
        """Gets the sweep_kernel_cluster_node of this OrmSweep.  # noqa: E501


        :return: The sweep_kernel_cluster_node of this OrmSweep.  # noqa: E501
        :rtype: int
        """
        return self._sweep_kernel_cluster_node

    @sweep_kernel_cluster_node.setter
    def sweep_kernel_cluster_node(self, sweep_kernel_cluster_node):
        """Sets the sweep_kernel_cluster_node of this OrmSweep.


        :param sweep_kernel_cluster_node: The sweep_kernel_cluster_node of this OrmSweep.  # noqa: E501
        :type sweep_kernel_cluster_node: int
        """

        self._sweep_kernel_cluster_node = sweep_kernel_cluster_node

    @property
    def sweep_kernel_image(self):
        """Gets the sweep_kernel_image of this OrmSweep.  # noqa: E501


        :return: The sweep_kernel_image of this OrmSweep.  # noqa: E501
        :rtype: int
        """
        return self._sweep_kernel_image

    @sweep_kernel_image.setter
    def sweep_kernel_image(self, sweep_kernel_image):
        """Sets the sweep_kernel_image of this OrmSweep.


        :param sweep_kernel_image: The sweep_kernel_image of this OrmSweep.  # noqa: E501
        :type sweep_kernel_image: int
        """

        self._sweep_kernel_image = sweep_kernel_image

    @property
    def sweep_kernel_resource_spec(self):
        """Gets the sweep_kernel_resource_spec of this OrmSweep.  # noqa: E501


        :return: The sweep_kernel_resource_spec of this OrmSweep.  # noqa: E501
        :rtype: int
        """
        return self._sweep_kernel_resource_spec

    @sweep_kernel_resource_spec.setter
    def sweep_kernel_resource_spec(self, sweep_kernel_resource_spec):
        """Sets the sweep_kernel_resource_spec of this OrmSweep.


        :param sweep_kernel_resource_spec: The sweep_kernel_resource_spec of this OrmSweep.  # noqa: E501
        :type sweep_kernel_resource_spec: int
        """

        self._sweep_kernel_resource_spec = sweep_kernel_resource_spec

    @property
    def sweep_organization(self):
        """Gets the sweep_organization of this OrmSweep.  # noqa: E501


        :return: The sweep_organization of this OrmSweep.  # noqa: E501
        :rtype: int
        """
        return self._sweep_organization

    @sweep_organization.setter
    def sweep_organization(self, sweep_organization):
        """Sets the sweep_organization of this OrmSweep.


        :param sweep_organization: The sweep_organization of this OrmSweep.  # noqa: E501
        :type sweep_organization: int
        """

        self._sweep_organization = sweep_organization

    @property
    def sweep_project(self):
        """Gets the sweep_project of this OrmSweep.  # noqa: E501


        :return: The sweep_project of this OrmSweep.  # noqa: E501
        :rtype: int
        """
        return self._sweep_project

    @sweep_project.setter
    def sweep_project(self, sweep_project):
        """Sets the sweep_project of this OrmSweep.


        :param sweep_project: The sweep_project of this OrmSweep.  # noqa: E501
        :type sweep_project: int
        """

        self._sweep_project = sweep_project

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OrmSweep.  # noqa: E501


        :return: The updated_dt of this OrmSweep.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OrmSweep.


        :param updated_dt: The updated_dt of this OrmSweep.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    @property
    def volume_mounts(self):
        """Gets the volume_mounts of this OrmSweep.  # noqa: E501


        :return: The volume_mounts of this OrmSweep.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._volume_mounts

    @volume_mounts.setter
    def volume_mounts(self, volume_mounts):
        """Sets the volume_mounts of this OrmSweep.


        :param volume_mounts: The volume_mounts of this OrmSweep.  # noqa: E501
        :type volume_mounts: dict(str, object)
        """

        self._volume_mounts = volume_mounts

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmSweep):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmSweep):
            return True

        return self.to_dict() != other.to_dict()
